==> dnet-oai-utils-2.0.0-20140710.160144-18-sources.jar: eu/dnetlib/data/information/oai/publisher/conf/OAIConfigurationWriter.java <==
package eu.dnetlib.data.information.oai.publisher.conf;

import java.util.Collection;
import java.util.List;

import javax.annotation.Resource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import eu.dnetlib.data.information.oai.publisher.PublisherField;
import eu.dnetlib.data.information.oai.publisher.info.MDFInfo;
import eu.dnetlib.data.information.oai.publisher.info.SetInfo;
import eu.dnetlib.enabling.is.lookup.rmi.ISLookUpException;
import eu.dnetlib.enabling.is.registry.rmi.ISRegistryException;
import eu.dnetlib.enabling.is.registry.rmi.ISRegistryService;
import eu.dnetlib.enabling.tools.ServiceLocator;

public class OAIConfigurationWriter {

	private static final Log log = LogFactory.getLog(OAIConfigurationWriter.class); // NOPMD by marko on 11/24/08 5:02 PM

	@Resource(name = "registryLocator")
	private ServiceLocator<ISRegistryService> registryLocator;

	@Resource(name = "oaiConfigurationExistReader")
	private OAIConfigurationReader configuration;

	public boolean updateMetadataFormat(final String mdPrefix, final MDFInfo newInfo) throws ISRegistryException {

		final String xUpdate = "update replace //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']"
				+ "//CONFIGURATION//METADATAFORMAT[./@metadataPrefix/string()='" + mdPrefix + "'] with <METADATAFORMAT exportable=\"" + newInfo.isEnabled()
				+ "\" metadataPrefix=\"" + newInfo.getPrefix() + "\">" + "<NAMESPACE>" + newInfo.getNamespace() + "</NAMESPACE><SCHEMA>" + newInfo.getSchema()
				+ "</SCHEMA><SOURCE_METADATA_FORMAT interpretation=\"" + newInfo.getSourceFormatInterpretation() + "\" layout=\""
				+ newInfo.getSourceFormatLayout() + "\" name=\"" + newInfo.getSourceFormatName() + "\"/><TRANSFORMATION_RULE>"
				+ newInfo.getTransformationRuleID() + "</TRANSFORMATION_RULE><BASE_QUERY>" + newInfo.getBaseQuery() + "</BASE_QUERY></METADATAFORMAT>";
		return this.registryLocator.getService().executeXUpdate(xUpdate);
	}

	public boolean addMetadataFormat(final MDFInfo newInfo) throws ISRegistryException {

		String action = "update insert ";
		String newNode = "<METADATAFORMAT metadataPrefix='" + newInfo.getPrefix() + "' exportable='" + newInfo.isEnabled() + "' ><NAMESPACE>"
				+ newInfo.getNamespace() + "</NAMESPACE><SCHEMA>" + newInfo.getSchema() + "</SCHEMA>" + "<SOURCE_METADATA_FORMAT interpretation='"
				+ newInfo.getSourceFormatInterpretation() + "' layout='" + newInfo.getSourceFormatLayout() + "' name='" + newInfo.getSourceFormatName()
				+ "' /><TRANSFORMATION_RULE>" + newInfo.getTransformationRuleID() + "</TRANSFORMATION_RULE><BASE_QUERY>" + newInfo.getBaseQuery()
				+ "</BASE_QUERY></METADATAFORMAT>";
		String targetNode = "//RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION/METADATAFORMATS";

		String xUpdate = action + newNode + " into " + targetNode;
		return this.registryLocator.getService().executeXUpdate(xUpdate);
	}

	public boolean deleteMetadataFormat(final String mdPrefix) throws ISRegistryException {
		String xUpdate = "update delete //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION//METADATAFORMATS/METADATAFORMAT[./@metadataPrefix/string()='"
				+ mdPrefix + "']";
		return this.registryLocator.getService().executeXUpdate(xUpdate);
	}

	public boolean updateOAISet(final String setSpec, final SetInfo newInfo) throws ISRegistryException {
		final String xUpdate = "update replace //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']"
				+ "//CONFIGURATION//OAISET[spec/text()='" + setSpec + "'] with " + "<OAISET enabled=\"" + newInfo.isEnabled() + "\">" + "<spec>"
				+ newInfo.getSetSpec() + "</spec>" + "<name>" + newInfo.getSetName() + "</name>" + "<description>" + newInfo.getSetDescription()
				+ "</description>" + "<query>" + newInfo.getQuery() + "</query></OAISET>";

		return this.registryLocator.getService().executeXUpdate(xUpdate);
	}

	public boolean addOAISet(final SetInfo newInfo) throws ISRegistryException {
		String action = "update insert ";
		String newNode = "<OAISET enabled=\"" + newInfo.isEnabled() + "\">" + "<spec>" + newInfo.getSetSpec() + "</spec>" + "<name>" + newInfo.getSetName()
				+ "</name>" + "<description>" + newInfo.getSetDescription() + "</description>" + "<query>" + newInfo.getQuery() + "</query></OAISET>";
		String targetNode = "//RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION/OAISETS";

		String xUpdate = action + newNode + " into " + targetNode;
		return this.registryLocator.getService().executeXUpdate(xUpdate);
	}

	public boolean deleteOAISet(final String setSpec) throws ISRegistryException {
		String xUpdate = "update delete //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION//OAISET[spec/text()='"
				+ setSpec + "']";
		return this.registryLocator.getService().executeXUpdate(xUpdate);
	}

	public boolean updateIndices(final String format, final String layout, final String interpretation, final List<PublisherField> indexes)
			throws ISRegistryException {
		boolean dropped = this.dropIndexesFor(format, layout, interpretation);
		String xUpdateAction = "update insert ";
		String nodeTemplate = " <SOURCE name='" + format + "' layout='" + layout + "' interpretation='" + interpretation + "' ";
		String targetTemplate = "//RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION/INDICES/INDEX";
		if (!dropped) return false;
		for (PublisherField field : indexes) {
			String targetNode = targetTemplate + "[@name='" + field.getFieldName() + "']";
			Collection<String> paths = field.getSources().get(format + "-" + layout + "-" + interpretation);
			for (String p : paths) {
				// insert one SOURCE node at a time, otherwise Exist complaints.
				String node = nodeTemplate + " path=\"" + p + "\" />";
				String xUpdate = xUpdateAction + node + " into " + targetNode;
				log.info("TO RUN: \n" + xUpdate);
				boolean done = this.registryLocator.getService().executeXUpdate(xUpdate);
				if (!done) {
					log.fatal("Could not set source \n" + node + "\n to index " + field.getFieldName());
					return false;
				}
			}
			// finally let's update the repeatability
			String updateRepeatability = "update value " + targetNode + "/@repeatable with '" + field.isRepeatable() + "'";
			boolean done = this.registryLocator.getService().executeXUpdate(updateRepeatability);
			if (!done) {
				log.fatal("Could not update repeatability attribute to index " + field.getFieldName());
				return false;
			}

		}
		return true;
	}

	private boolean dropIndexesFor(final String format, final String layout, final String interpretation) throws ISRegistryException {
		String xUpdate = "update delete //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION//INDEX/SOURCE[./@interpretation/string()='"
				+ interpretation + "' and ./@name/string()='" + format + "' and ./@layout/string()='" + layout + "'] ";
		return this.registryLocator.getService().executeXUpdate(xUpdate);
	}

	public boolean addNewIndex(final String format,
			final String layout,
			final String interpretation,
			final String indexName,
			final boolean isRepeatable,
			final String[] paths) throws ISLookUpException, ISRegistryException {
		String action = "update insert ";
		String nodeTemplate = " <SOURCE name='" + format + "' layout='" + layout + "' interpretation='" + interpretation + "' ";
		String targetTemplate = "//RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION/INDICES";
		if (this.configuration.getFieldNames().contains(indexName)) {
			String targetNode = targetTemplate + "/INDEX[@name/string()='" + indexName + "']";
			for (String p : paths) {
				// insert one SOURCE node at a time, otherwise Exist complaints.
				String node = nodeTemplate + " path=\"" + p + "\" />";
				String xUpdate = action + node + " into " + targetNode;
				log.info("TO RUN: \n" + xUpdate);
				boolean done = this.registryLocator.getService().executeXUpdate(xUpdate);
				// log.info("Could not successfully run the folowing xUpdate: \n" + xUpdate);
				if (!done) return false;
			}
		} else {
			String targetNode = targetTemplate;
			String node = "<INDEX name='" + indexName + "' repeatable='" + isRepeatable + "'>";
			for (String p : paths) {
				node += nodeTemplate + " path=\"" + p + "\" />";
			}
			node += "</INDEX>";
			String xUpdate = action + node + " into " + targetNode;
			log.info("TO RUN: \n" + xUpdate);
			boolean done = this.registryLocator.getService().executeXUpdate(xUpdate);
			if (!done) return false;
		}
		return true;
	}

	public ServiceLocator<ISRegistryService> getRegistryLocator() {
		return registryLocator;
	}

	public void setRegistryLocator(final ServiceLocator<ISRegistryService> registryLocator) {
		this.registryLocator = registryLocator;
	}

	public OAIConfigurationReader getConfiguration() {
		return configuration;
	}

	public void setConfiguration(final OAIConfigurationReader configuration) {
		this.configuration = configuration;
	}

}

==> dnet-oai-utils-3.1.1-20150330.122938-6-sources.jar: eu/dnetlib/data/information/oai/publisher/conf/OAIConfigurationWriter.java <==
package eu.dnetlib.data.information.oai.publisher.conf;

import java.util.Collection;
import java.util.List;

import javax.annotation.Resource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import eu.dnetlib.data.information.oai.publisher.PublisherField;
import eu.dnetlib.data.information.oai.publisher.info.MDFInfo;
import eu.dnetlib.data.information.oai.publisher.info.SetInfo;
import eu.dnetlib.enabling.is.lookup.rmi.ISLookUpException;
import eu.dnetlib.enabling.is.registry.rmi.ISRegistryException;
import eu.dnetlib.enabling.is.registry.rmi.ISRegistryService;
import eu.dnetlib.enabling.locators.UniqueServiceLocator;
import eu.dnetlib.miscutils.functional.string.EscapeXml;

public class OAIConfigurationWriter {

	private static final Log log = LogFactory.getLog(OAIConfigurationWriter.class); // NOPMD by marko on 11/24/08 5:02 PM

	@Resource
	private UniqueServiceLocator serviceLocator;

	@Resource(name = "oaiConfigurationExistReader")
	private OAIConfigurationReader configuration;

	private boolean execute(final String xUpdate) throws ISRegistryException {
		log.debug("Running XUpdate:\n" + xUpdate);
		boolean done = this.serviceLocator.getService(ISRegistryService.class).executeXUpdate(xUpdate);
		if (!done) {
			log.fatal("Could not perform the following Xupdate:\n" + xUpdate);
		}
		return done;
	}

	public boolean updateMetadataFormat(final String mdPrefix, final MDFInfo newInfo) throws ISRegistryException {

		final String xUpdate = "update replace //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']"
				+ "//CONFIGURATION//METADATAFORMAT[./@metadataPrefix/string()='" + mdPrefix + "'] with <METADATAFORMAT exportable=\"" + newInfo.isEnabled()
				+ "\" metadataPrefix=\"" + newInfo.getPrefix() + "\">" + "<NAMESPACE>" + newInfo.getNamespace() + "</NAMESPACE><SCHEMA>" + newInfo.getSchema()
				+ "</SCHEMA><SOURCE_METADATA_FORMAT interpretation=\"" + newInfo.getSourceFormatInterpretation() + "\" layout=\""
				+ newInfo.getSourceFormatLayout() + "\" name=\"" + newInfo.getSourceFormatName() + "\"/><TRANSFORMATION_RULE>"
				+ newInfo.getTransformationRuleID() + "</TRANSFORMATION_RULE><BASE_QUERY>" + new EscapeXml().evaluate(newInfo.getBaseQuery())
				+ "</BASE_QUERY></METADATAFORMAT>";
		return this.execute(xUpdate);
	}

	public boolean addMetadataFormat(final MDFInfo newInfo) throws ISRegistryException {

		String action = "update insert ";
		String newNode = "<METADATAFORMAT metadataPrefix='" + newInfo.getPrefix() + "' exportable='" + newInfo.isEnabled() + "' ><NAMESPACE>"
				+ newInfo.getNamespace() + "</NAMESPACE><SCHEMA>" + newInfo.getSchema() + "</SCHEMA>" + "<SOURCE_METADATA_FORMAT interpretation='"
				+ newInfo.getSourceFormatInterpretation() + "' layout='" + newInfo.getSourceFormatLayout() + "' name='" + newInfo.getSourceFormatName()
				+ "' /><TRANSFORMATION_RULE>" + newInfo.getTransformationRuleID() + "</TRANSFORMATION_RULE><BASE_QUERY>"
				+ new EscapeXml().evaluate(newInfo.getBaseQuery()) + "</BASE_QUERY></METADATAFORMAT>";
		String targetNode = "//RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION/METADATAFORMATS";

		String xUpdate = action + newNode + " into " + targetNode;
		return this.execute(xUpdate);
	}

	public boolean deleteMetadataFormat(final String mdPrefix) throws ISRegistryException {
		String xUpdate =
				"update delete //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION//METADATAFORMATS/METADATAFORMAT[./@metadataPrefix/string()='"
						+ mdPrefix + "']";
		return this.execute(xUpdate);
	}

	public boolean updateOAISet(final String setSpec, final SetInfo newInfo) throws ISRegistryException {
		final String xUpdate = "update replace //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']"
				+ "//CONFIGURATION//OAISET[spec/text()='" + setSpec + "'] with " + "<OAISET enabled=\"" + newInfo.isEnabled() + "\">" + "<spec>"
				+ newInfo.getSetSpec() + "</spec>" + "<name>" + newInfo.getSetName() + "</name>" + "<description>" + newInfo.getSetDescription()
				+ "</description>" + "<query>" + new EscapeXml().evaluate(newInfo.getQuery()) + "</query></OAISET>";

		return this.execute(xUpdate);
	}

	public boolean addOAISet(final SetInfo newInfo) throws ISRegistryException {
		String action = "update insert ";
		String newNode = "<OAISET enabled=\"" + newInfo.isEnabled() + "\">" + "<spec>" + newInfo.getSetSpec() + "</spec>" + "<name>" + newInfo.getSetName()
				+ "</name>" + "<description>" + newInfo.getSetDescription() + "</description>" + "<query>" + new EscapeXml().evaluate(newInfo.getQuery())
				+ "</query></OAISET>";
		String targetNode = "//RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION/OAISETS";

		String xUpdate = action + newNode + " into " + targetNode;
		return this.execute(xUpdate);
	}

	public boolean deleteOAISet(final String setSpec) throws ISRegistryException {
		String xUpdate =
				"update delete //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION//OAISET[spec/text()='"
						+ setSpec + "']";
		return this.execute(xUpdate);
	}

	public boolean updateIndices(final String format, final String layout, final String interpretation, final List<PublisherField> indexes)
			throws ISRegistryException {
		boolean dropped = this.dropIndexesFor(format, layout, interpretation);
		String xUpdateAction = "update insert ";
		String nodeTemplate = " <SOURCE name='" + format + "' layout='" + layout + "' interpretation='" + interpretation + "' ";
		String targetTemplate = "//RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION/INDICES/INDEX";
		if (!dropped) { return false; }
		for (PublisherField field : indexes) {
			String targetNode = targetTemplate + "[@name='" + field.getFieldName() + "']";
			Collection<String> paths = field.getSources().get(format + "-" + layout + "-" + interpretation);
			for (String p : paths) {
				// insert one SOURCE node at a time, otherwise Exist complaints.
				String node = nodeTemplate + " path=\"" + p + "\" />";
				String xUpdate = xUpdateAction + node + " into " + targetNode;
				boolean done = this.execute(xUpdate);
				if (!done) { return false; }
			}
			// finally let's update the repeatability
			String updateRepeatability = "update value " + targetNode + "/@repeatable with '" + field.isRepeatable() + "'";
			boolean done = this.execute(updateRepeatability);
			if (!done) { return false; }
		}
		return true;
	}

	private boolean dropIndexesFor(final String format, final String layout, final String interpretation) throws ISRegistryException {
		String xUpdate =
				"update delete //RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION//INDEX/SOURCE[./@interpretation/string()='"
						+ interpretation + "' and ./@name/string()='" + format + "' and ./@layout/string()='" + layout + "'] ";
		return this.execute(xUpdate);
	}

	public boolean addNewIndex(final String format,
			final String layout,
			final String interpretation,
			final String indexName,
			final boolean isRepeatable,
			final String[] paths) throws ISLookUpException, ISRegistryException {
		String action = "update insert ";
		String nodeTemplate = " <SOURCE name='" + format + "' layout='" + layout + "' interpretation='" + interpretation + "' ";
		String targetTemplate = "//RESOURCE_PROFILE[.//RESOURCE_TYPE/@value='OAIPublisherConfigurationDSResourceType']//CONFIGURATION/INDICES";
		if (this.configuration.getFieldNames().contains(indexName)) {
			String targetNode = targetTemplate + "/INDEX[@name/string()='" + indexName + "']";
			for (String p : paths) {
				// insert one SOURCE node at a time, otherwise Exist complaints.
				String node = nodeTemplate + " path=\"" + p + "\" />";
				String xUpdate = action + node + " into " + targetNode;
				boolean done = this.execute(xUpdate);
				if (!done) { return false; }
			}
		} else {
			String targetNode = targetTemplate;
			String node = "<INDEX name='" + indexName + "' repeatable='" + isRepeatable + "'>";
			for (String p : paths) {
				node += nodeTemplate + " path=\"" + p + "\" />";
			}
			node += "</INDEX>";
			String xUpdate = action + node + " into " + targetNode;
			boolean done = this.execute(xUpdate);
			if (!done) { return false; }
		}
		return true;
	}

	public OAIConfigurationReader getConfiguration() {
		return configuration;
	}

	public void setConfiguration(final OAIConfigurationReader configuration) {
		this.configuration = configuration;
	}

}
